.. _apidoc:

############################
Generated Code documentation
############################

.. warning:: This generated documentation is **not intended to be an API**.
    All code here change at anytime.

.. toctree::
    :maxdepth: 4
    :glob:

    *
